==> ws-v3.20-3-src.tar.gz: ws-v3.20-3/include/WSCvmifield.h <==
//
// Copyright (C) 1999-2002 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSCVMIFIELD_H
#define WSCVMIFIELD_H

#include <WScom.h>
#include <WSCvifield.h>
#define WSCvmifield_VER  1000

class WSCvmifield    :public WSCvifield{
    char _set_base_work_flag;

  protected:
    virtual long _cursor_move(char direction);

  public:
    WSCvmifield(WSCbase*,char*);

    void getCursorBase(long*,long*); 
    void setCursorBase(long,long); 

    WSMFguiClassDef(WSCvmifield,WSCvifield);
    WSMFversionDef(WSCvmifield);
};

#endif //WSCVMIFIELD_H

==> ws-v3.80.5-src.tar.gz: ws-v3.80-5/include/WSCvmifield.h <==
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of WideStudio Development Team
// shall not be used in advertising or otherwise to promote the sale, use or
// other dealings in this Software without prior written authorization from
// WideStudio Development Team.

#ifndef WSCVMIFIELD_H
#define WSCVMIFIELD_H

#include <WScom.h>
#include <WSCvifield.h>
#define WSCvmifield_VER  1000

class WSCvmifield    :public WSCvifield{
    char _set_base_work_flag;

  protected:
    WSDLEX32 virtual long _cursor_move(char direction);

  public:
    WSDLEX32 WSCvmifield(WSCbase*,char*);

    WSDLEX32 void getCursorBase(long*,long*); 
    WSDLEX32 void setCursorBase(long,long); 

    WSMFguiClassDef(WSCvmifield,WSCvifield);
    WSMFversionDef(WSCvmifield);
};

#endif //WSCVMIFIELD_H
